@@ -351,7 +351,7 @@ from ae.core import DEBUG_LEVELS
 from ae.console import ConsoleApp                                                       # type: ignore
 
 
-__version__ = '0.1.50'
+__version__ = '0.1.51'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -477,10 +477,13 @@ def flow_popup_class_name(flow_id: str) -> str:
     """ determine name of the Popup class for the given flow id.
 
     :param flow_id:         flow id.
-    :return:                name of the Popup class.
+    :return:                name of the Popup class. Please note that the action `open` will not be added
+                            to the returned class name.
     """
     flow, _index = flow_key_split(flow_id)
     action, obj = flow_action_split(flow)
+    if action == 'open':
+        action = ''
     return f'{snake_to_camel(obj)}{action.capitalize()}Popup'
 
 
